const fs = require('fs');
const logger = require('komodo-sdk/logger');

const config = require('komodo-sdk/config');
const messagingClient = require('komodo-center-messaging-client-lib');
const transport = require('../transport');

messagingClient.setTransport(transport);

const mailparser = require('../mailparser-wrapper');

module.exports = async (msgFilename) => {
    const msg = await fs.promises.readFile(msgFilename);

    if (!msg) {
        logger.warn('Can not read message file', { msgFile: msgFilename });
        return;
    }

    const parsedMsg = await mailparser(msg);

    if (!parsedMsg || !parsedMsg.headers) {
        logger.warn('Invalid message');
        return;
    }

    const from = parsedMsg.headers.get('from').text;
    const imsi = parsedMsg.headers.get('imsi');
    const { text } = parsedMsg;

    logger.info('Message parsed', {
        from, imsi, text,
    });

    if (!from || !imsi || !text) {
        return;
    }

    messagingClient.onIncomingMessage({
        me: imsi,
        partner: `${from}${config.number_suffix || ''}`,
        partner_raw: from,
        msg: text,
        origin_label: imsi || 'UNKNOWN',
        origin_transport: 'SMS',
        origin_partner: from,
        do_not_forward_to_core: true,
        is_outgoing: true,
    });
};
